;; -*- emacs-lisp -*-
;;; mst-colours.el --- my colour scheme

;; Author: Mark Triggs <mst@dishevelled.net>
;; $Id: mst-colours.el,v 1.77 2007/03/04 11:06:41 mst Exp $

;; This file is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; This file is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

;;; Commentary:

;; Screenshot shown at http://dishevelled.net/shots/emacs-theme.png

;;; Code:
(require 'font-lock)

(defun set-frame-alist (sym-property value)
  (let ((prop (assoc sym-property default-frame-alist)))
    (setq default-frame-alist
          (cons (cons sym-property value)
                (if prop
                    (remove prop default-frame-alist)
                  default-frame-alist))))
  (let ((prop (assoc sym-property initial-frame-alist)))
    (setq initial-frame-alist
          (cons (cons sym-property value)
                (if prop
                    (remove prop initial-frame-alist)
                  initial-frame-alist)))))

(defmacro ensure-eval-all (&rest forms)
  "Wrap each individual form in an IGNORE-ERRORS"
  `(progn ,@(mapcar #'(lambda (f)
                        `(condition-case err ,f
                           (error () (when (fboundp 'warn)
                                       (warn (format "Error with: %s" err))))))
                    forms)))


;; Emacs Appearance ;;
(set-frame-alist 'cursor-color "black")

(ensure-eval-all ; We want to execute as many forms as we possibly can..
 (case window-system
   (x (set-face-background 'modeline "gray80")
      (set-face-foreground 'modeline "black"))
   (otherwise
    (set-face-foreground 'modeline "black")
    (set-face-background 'modeline "white")))

 (set-face-attribute 'modeline nil :box nil)
 (set-face-attribute 'modeline nil :weight 'normal)

 (set-face-attribute 'header-line nil :box nil)

 (set-face-background 'header-line "Gray85")
 (set-face-foreground 'header-line "black")
 (set-face-attribute 'header-line nil :box '(:line-width 1 :color "black"))

 (set-face-foreground 'mode-line-inactive "gray40")
 (set-face-background 'mode-line-inactive "gray85")
 (set-face-attribute 'mode-line-inactive nil :weight 'normal)
 (set-face-attribute 'mode-line-inactive nil :box nil)

 (set-face-foreground 'default "black")
 (set-frame-alist 'foreground-color "black")
 (set-face-background 'default "#d9d9f0")
 (set-frame-alist 'background-color "#d9d9f0")

 (set-face-background 'fringe "gray85")

 (set-face-foreground 'font-lock-string-face "#0000BB")

 (set-face-foreground 'font-lock-comment-face "#1F1FFF")
 (set-face-foreground 'font-lock-comment-face "DodgerBlue4")

 (set-face-foreground 'font-lock-keyword-face "black")
 (set-face-attribute 'font-lock-keyword-face nil :weight 'bold)

 (set-face-foreground 'font-lock-function-name-face "#0000BB")
 (set-face-attribute 'font-lock-function-name-face nil :weight 'semi-bold)

 (set-face-foreground 'font-lock-variable-name-face "#0000BB")
 (set-face-attribute 'font-lock-variable-name-face nil :weight 'normal)

 (set-face-foreground 'font-lock-constant-face "#0000BB")
 (set-face-attribute 'font-lock-constant-face nil :weight 'normal)

 (set-face-foreground 'font-lock-builtin-face "black")
 (set-face-attribute 'font-lock-builtin-face nil :weight 'bold)

 (set-face-foreground 'minibuffer-prompt "black")
 (set-face-font 'minibuffer-prompt (face-font 'default))
 (set-face-attribute 'minibuffer-prompt nil :weight 'bold)

 (set-face-foreground 'font-lock-type-face "black")
 (set-face-attribute 'font-lock-type-face nil :weight 'bold)

 (set-face-foreground 'font-lock-doc-face "Blue3")

 (set-face-foreground 'region "black")
 (set-face-background 'region "gray88")
 (set-face-foreground 'italic "gray40")

 (set-face-foreground 'hi-red-b "red")
 (set-face-attribute 'hi-red-b nil :weight 'bold)

 (set-face-background 'show-paren-match-face (face-background 'default))
 (set-face-foreground 'show-paren-match-face "#0000BB")
 (set-face-attribute 'show-paren-match-face nil :weight 'extra-bold)

 (set-face-background 'isearch "#AAAAFF")

 (eval-after-load "highline"
   '(progn (set-face-attribute 'highline-face nil :weight 'bold)
           (set-face-foreground 'highline-face (face-foreground 'default))
           (set-face-background 'highline-face (face-background 'default))))


 (set-face-foreground 'highlight "#DEF")
 (set-face-background 'highlight (face-background 'default))
 (set-face-attribute 'highlight nil :box 1)

 (eval-after-load "flyspell"
   '(progn
      (set-face-foreground 'flyspell-incorrect-face "Gray60")
      (set-face-attribute 'flyspell-incorrect-face nil :box
                          '(:line-width 2 :color "black"))
      (set-face-attribute 'flyspell-incorrect-face nil :underline nil)))

 (set-face-foreground 'widget-button-face "Gray30")
 (set-face-attribute 'widget-button-face nil :weight 'bold :underline nil)

 ;; cperl horribleness
 (eval-after-load "cperl-mode"
   '(progn (set-face-foreground 'cperl-nonoverridable-face "black")
           (set-face-attribute 'cperl-nonoverridable-face nil :weight 'bold)
           (copy-face 'font-lock-variable-name-face 'cperl-hash-face)
           (copy-face 'font-lock-variable-name-face 'cperl-array-face)
           (set-face-background 'cperl-array-face
                                (face-background 'default))
           (set-face-background 'cperl-hash-face
                                (face-background 'default))))

 ;; emacs-wiki
 (eval-after-load "emacs-wiki"
   '(progn
      (set-face-foreground 'emacs-wiki-link-face "#0000BB")
      (set-face-attribute 'emacs-wiki-link-face nil :underline t)))

 ;; Info
 (eval-after-load "info"
   '(set-face-foreground 'info-xref "#0000BB"))

 ;; Message sending
 (eval-after-load "message"
   '(progn
      (set-face-foreground 'message-cited-text-face "SteelBlue4")
      (set-face-foreground 'message-header-name-face "Gray50")
      (set-face-attribute 'message-header-name-face nil :weight 'bold)))

 ;; LaTeX
 (eval-after-load "font-latex"
   '(progn
      (set-face-foreground 'font-latex-italic-face "gray50")
      (set-face-foreground 'font-latex-bold-face "gray40")
      (set-face-foreground 'font-latex-math-face "gray50")
      (set-face-foreground 'font-latex-warning-face "red"))))


 (eval-after-load "sh-script"
   '(set-face-foreground 'sh-heredoc-face
                         (face-foreground 'font-lock-string-face)))

;; SLIME
(eval-after-load "slime"
  '(progn
     (set-face-foreground 'slime-repl-inputed-output-face
                          (face-foreground 'default))))

(eval-after-load "mmm-mode"
  '(set-face-background 'mmm-default-submode-face (face-background 'default)))

(eval-after-load "erc"
  '(cond ((and (featurep 'color-theme) window-system)
          ;; Tweak colours if we are running in a window system
          (set-face-foreground 'erc-timestamp-face "gray80")
          (set-face-foreground 'erc-direct-msg-face "black")
          (set-face-foreground 'erc-prompt-face "black")
          (set-face-background 'erc-prompt-face (face-background 'default))
          (set-face-foreground 'erc-default-face "#abc")
          (set-face-foreground 'erc-keyword-face "blue")
          ;; (set-face-foreground 'erc-input-face "SteelBlue4")
          (set-face-foreground 'erc-input-face "gray45")
          (set-face-foreground 'erc-nick-msg-face "black")
          (setq erc-nick-msg-face 'bold)
          (set-face-foreground 'erc-notice-face "#5080AA")
          (set-face-attribute 'erc-notice-face nil :weight 'normal))
         (t (set-face-foreground 'erc-direct-msg-face "white")
            (set-face-foreground 'erc-default-face "white")
            (set-face-foreground 'erc-input-face "white")
            (set-face-foreground 'erc-timestamp-face "white")
            (setq erc-nick-msg-face 'bold)
            (set-face-foreground 'erc-nick-msg-face "white")
            (set-face-foreground 'erc-notice-face "white"))))



(provide 'mst-colours)
;;; mst-colours.el ends here
